@@ -846,7 +846,7 @@ sub GetKeyAndSource {
 # Read rules file for use in pcd2html_create_{jpg,html}
 #
 sub GetParametersFromRules {
-  my ( $pickey, $picnum, $num, $name, $image, $source, $O, $E, $Q, $line );
+  my ( $pickey, $picnum, $num, $name, $image, $source, $O, $E, $Q, $line, $WikiPediaLink );
 
   $pickey = $_[0];
   $picnum = $_[1];
@@ -860,7 +860,7 @@ sub GetParametersFromRules {
         $num   = "$1_extra" ;
         $name  = "$2" ;
         $image = $1 . "_extra" . $name ;
-        $O = $Q = $E = "" ; # we need defined values for these variables
+        $O = $Q = $E = $WikiPediaLink = "" ; # we need defined values for these variables
       } else {
         /(\w*):(\w*) *([^ ]*).*/ ;
         $num   = "$1_$2" ;
@@ -872,13 +872,18 @@ sub GetParametersFromRules {
 ##      if ( defined ($Q = GetOperationParameter($line, "Q", "[^\\Q]*Q([0-9]*)" )) ) { 
 ##  Hmmm, I'm not really sure why I once placed the '\\' here, but now it is not good any more
         $Q = GetOperationParameter($line, "Q", "[^Q]*Q([0-9]*)" ) ;
+	if ( /{(\w*\.jpe?g)}/ ) {
+	    $WikiPediaLink = $1 ;
+	} else {
+	    $WikiPediaLink = "" ;
+	}
         last ;
       }
     }
   }
   close RULES ;
 
-  return ($num, $name, $image, $O, $Q, $E );
+  return ($num, $name, $image, $O, $Q, $E, $WikiPediaLink);
 }
 
 sub CheckChanges {
